This is an automated email from the ASF dual-hosted git repository.

lidavidm pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/arrow.git


The following commit(s) were added to refs/heads/main by this push:
     new 18c012aab8 GH-34017: [Python][FlightRPC][Doc] Fix 
FlightStreamReader.read_chunk's docstring (#35583)
18c012aab8 is described below

commit 18c012aab8d48fc4fc76f015f45e3712251dd770
Author: Julien Jerphanion <[email protected]>
AuthorDate: Mon May 15 16:56:19 2023 +0200

    GH-34017: [Python][FlightRPC][Doc] Fix FlightStreamReader.read_chunk's 
docstring (#35583)
    
    ### Rationale for this change
    
    Addresses https://github.com/apache/arrow/issues/34017.
    
    ### What changes are included in this PR?
    
    Simple docstring fixes.
    
    ### Are these changes tested?
    
    No (must they be test?)
    
    ### Are there any user-facing changes?
    
    Yes.
    
    Authored-by: Julien Jerphanion <[email protected]>
    Signed-off-by: David Li <[email protected]>
---
 python/pyarrow/_flight.pyx | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/python/pyarrow/_flight.pyx b/python/pyarrow/_flight.pyx
index ca594a2614..6f5cd03cd5 100644
--- a/python/pyarrow/_flight.pyx
+++ b/python/pyarrow/_flight.pyx
@@ -1002,12 +1002,12 @@ cdef class _MetadataRecordBatchReader(_Weakrefable, 
_ReadPandasMixin):
         return pyarrow_wrap_table(c_table)
 
     def read_chunk(self):
         """Read the next RecordBatch along with any metadata.
 
         Returns
         -------
-        data : RecordBatch
-            The next RecordBatch in the stream.
+        data : FlightStreamChunk
+            The next FlightStreamChunk in the stream.
         app_metadata : Buffer or None
             Application-specific metadata for the batch as defined by
             Flight.
@@ -1002,12 +1002,12 @@ cdef class _MetadataRecordBatchReader(_Weakrefable, 
 
     def read_chunk(self):
-        """Read the next RecordBatch along with any metadata.
+        """Read the next FlightStreamChunk along with any metadata.
 
         Returns

Reply via email to